@@ -3,7 +3,7 @@ from django.apps import AppConfig
 
 class BirdBathConfig(AppConfig):
     name = "birdbath"
+    default_auto_field = "django.db.models.AutoField"
 
     def ready(self):
-        from . import system_checks
-
+        from . import system_checks  # noqa: F401
