@@ -1,8 +1,16 @@
 from django.conf import settings
 
-BIRDBATH_REQUIRED = getattr(settings, "BIRDBATH_REQUIRED", True,)
+BIRDBATH_REQUIRED = getattr(
+    settings,
+    "BIRDBATH_REQUIRED",
+    True,
+)
 
-BIRDBATH_CHECKS = getattr(settings, "BIRDBATH_CHECKS", [],)
+BIRDBATH_CHECKS = getattr(
+    settings,
+    "BIRDBATH_CHECKS",
+    [],
+)
 BIRDBATH_PROCESSORS = getattr(
     settings,
     "BIRDBATH_PROCESSORS",
@@ -20,4 +28,3 @@ BIRDBATH_USER_ANONYMISER_EXCLUDE_EMAIL_RE = getattr(
 BIRDBATH_USER_ANONYMISER_EXCLUDE_SUPERUSERS = getattr(
     settings, "BIRDBATH_USER_ANONYMISER_EXCLUDE_SUPERUSERS", True
 )
-
